---
title: <span class="badge object-type-scalar"></span> PhilippinePeso
---
# <span class="badge object-type-scalar"></span> PhilippinePeso

Currency: Philippine Peso (PHP)

## Definition

```python
# Currency: Philippine Peso (PHP)
PhilippinePeso: typing.Literal["currencyPHP"] = "currencyPHP"
```
